@@ -22,16 +22,16 @@
 
 #if __BYTE_ORDER == __LITTLE_ENDIAN
 #ifndef be32toh
-#define be32toh(x) __bswap_32 (x)
+#define be32toh(x) bswap_32 (x)
 #endif
 #ifndef htobe32
-#define htobe32(x) __bswap_32 (x)
+#define htobe32(x) bswap_32 (x)
 #endif
 #ifndef be64toh
-#define be64toh(x) __bswap_64 (x)
+#define be64toh(x) bswap_64 (x)
 #endif
 #ifndef htobe64
-#define htobe64(x) __bswap_64 (x)
+#define htobe64(x) bswap_64 (x)
 #endif
 #ifndef le16toh
 #define le16toh(x) (x)
@@ -65,22 +65,22 @@
 #define htobe64(x) (x)
 #endif
 #ifndef le16toh
-#define le16toh(x) __bswap_16 (x)
+#define le16toh(x) bswap_16 (x)
 #endif
 #ifndef htole16
-#define htole16(x) __bswap_16 (x)
+#define htole16(x) bswap_16 (x)
 #endif
 #ifndef le32toh
-#define le32toh(x) __bswap_32 (x)
+#define le32toh(x) bswap_32 (x)
 #endif
 #ifndef htole32
-#define htole32(x) __bswap_32 (x)
+#define htole32(x) bswap_32 (x)
 #endif
 #ifndef le64toh
-#define le64toh(x) __bswap_64 (x)
+#define le64toh(x) bswap_64 (x)
 #endif
 #ifndef htole64
-#define htole64(x) __bswap_64 (x)
+#define htole64(x) bswap_64 (x)
 #endif
 #endif /* __BYTE_ORDER == __BIG_ENDIAN */
 
